"""
Base class for user-specific models that should be stored in encrypted databases.
Separate from the auth database Base.
"""

from sqlalchemy.ext.declarative import declarative_base

# Create a separate Base for user-specific models
UserBase = declarative_base()
