"""
LLM-specific rate limiting module.
"""

from .wrapper import create_rate_limited_llm_wrapper
from .detection import is_llm_rate_limit_error

__all__ = [
    "create_rate_limited_llm_wrapper",
    "is_llm_rate_limit_error",
]
