"""
Embedding providers for Local Deep Research.

This module provides a unified interface for different embedding providers,
similar to the LLM provider system. Supports:
- Sentence Transformers (HuggingFace)
- Ollama
- OpenAI
- Future: Cohere, Google Vertex AI, Azure OpenAI, etc.

Example:
    from local_deep_research.embeddings import get_embeddings

    embeddings = get_embeddings(
        provider="openai",
        model="text-embedding-3-small",
        settings_snapshot=settings
    )
"""

from .embeddings_config import (
    get_embeddings,
    get_available_embedding_providers,
    is_openai_embeddings_available,
    is_ollama_embeddings_available,
    is_sentence_transformers_available,
)

__all__ = [
    "get_embeddings",
    "get_available_embedding_providers",
    "is_openai_embeddings_available",
    "is_ollama_embeddings_available",
    "is_sentence_transformers_available",
]
