"""
Optimization metrics calculation.

This module is maintained for backward compatibility.
New code should use the unified metrics module.
"""

from ..metrics.calculation import (
    calculate_combined_score,
    calculate_quality_metrics,
    calculate_resource_metrics,
    calculate_speed_metrics,
)

__all__ = [
    "calculate_combined_score",
    "calculate_quality_metrics",
    "calculate_resource_metrics",
    "calculate_speed_metrics",
]
